OC.L10N.register(
    "files_trashbin",
    {
    "Couldn't delete %s permanently" : "No s'ha pogut esborrar permanentment %s",
    "Couldn't restore %s" : "No s'ha pogut restaurar %s",
    "Deleted files" : "Fitxers esborrats",
    "Restore" : "Recupera",
    "Delete permanently" : "Esborra permanentment",
    "Error" : "Error",
    "restored" : "restaurat",
    "No deleted files" : "No hi ha cap arxiu eliminat",
    "You will be able to recover deleted files from here" : "Des d'aquí es podran recuperar arxius eliminats",
    "No entries found in this folder" : "No hi ha entrades en aquesta carpeta",
    "Select all" : "Seleccionar tot",
    "Name" : "Nom",
    "Deleted" : "Eliminat",
    "Delete" : "Esborra"
},
"nplurals=2; plural=(n != 1);");
